function RunSingleTrial( output, iLink, trialData , display, tr)
    %initialize output
    output.message = 'GoodTrial'; %assume a good trial till proven otherwise
    output.RT = 0;
    %these define the rectangle dimansions of the fixation, cue and probe 
    fixRect = [display.fixXLoc - display.fixHalfBox...
            display.fixYLoc - display.fixHalfBox...
            display.fixXLoc + display.fixHalfBox...
            display.fixYLoc + display.fixHalfBox];

    gcRect = [display.fixXLoc - display.gcHalfBox...
            display.fixYLoc - display.gcHalfBox...
            display.fixXLoc + display.gcHalfBox...
            display.fixYLoc + display.gcHalfBox];
        
    space = KbName('space');
    escape = KbName('Escape');
    
    %display fixation and start trial timer
    if (iLink.doILink == 1)
        Screen('DrawTexture', display.w, display.probe , [],fixRect);         
        Screen('Flip', display.w );%to clear buffer  
            EyelinkDoDriftCorrection(iLink.el, display.fixXLoc, display.fixYLoc, 0, 1);
       % Start data recording to EDF file, BEFORE DISPLAY. */
        status=Eyelink('startrecording',1,1,1,0);
        if status~=0
        end
    else
        Screen('DrawTexture', display.w, display.probe , [],fixRect);         
        Screen('Flip', display.w );%to clear buffer  
        WaitSecs(.2);
    end
    if iLink.doILink
        Eyelink('SYNCTIME');
        Eyelink('message','TrialDisplay');
    end

    Screen('DrawTexture', display.w, display.black , [],gcRect);
    Screen('DrawTexture', display.w, trialData.tex , [],display.screenRect);
    trialStart = Screen('Flip', display.w );%to clear buffer  
   
    %event flags.  set these when the events happen in the timing loop
    maxTime = trialStart + display.maxProbeResponse;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%primary timing loop.  
%each if statement in here checks for one of our events like cue onset, or
%button response
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    while (GetSecs() < maxTime  && output.RT ==0)
        %%%%%%%%%%%%%%%%%%%%%%%%
        % 0) Make sure we still have an eye image
        if (iLink.doILink == 1)        
            if EYELINK('isconnected')==iLink.el.notconnected   % Check link often so we don't lock up if tracker lost
                output.message = 'ForceQuitProgram';
                Eyelink('stoprecording');
                Eyelink('message','TRIAL_OVER');
                Eyelink('message','TRIAL_ERROR_CONNECTION');
                return;
            end;
        end;

        %%%%%%%%%%%%%%%%%%%%%%%%
        % 1) poll for a keypress.  all keys are errors at this point
        [KeyIsDown, endrt, KeyCode]=KbCheck();
        if (KeyIsDown==1)
            output.RT = GetSecs() - probeOnset;
            
            if probePresentedFlag == 0
               output.message = 'EARLY_RESPONSE';
            end
             WaitSecs(.2);
            %return;
        end
        
         %%%%%%%%%%%%%%%%%%%%%%%%
        % 2) Where is the gaze?
        % Just check location, we will redraw based on it later
        if (iLink.doILink == 1)
            %use low level samples for onset times
            if Eyelink( 'NewFloatSampleAvailable') > 0
                evt = Eyelink( 'NewestFloatSample');
                try
                    currx = evt.gx(iLink.eye_used);
                    curry = evt.gy(iLink.eye_used);
                catch
                    currx = -1;
                    curry = -1;
                end
                if currx > 0
                    gcRect = [currx - display.gcHalfBox...
                            curry - display.gcHalfBox...
                            currx + display.gcHalfBox...
                            curry + display.gcHalfBox];
                else
                    output.lostSamples = output.lostSamples + 1;

                end
            end  
        else
            %use mouse coordinates
            [currx,curry,buttons] = GetMouse(display.w);
            gcRect = [currx - display.gcHalfBox...
                    curry - display.gcHalfBox...
                    currx + display.gcHalfBox...
                    curry + display.gcHalfBox];

        end;      
        
 
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %3  now draw gaze contingent
        if 1
            Screen('DrawTexture', display.w, trialData.tex , [],display.screenRect);
            Screen('DrawTexture', display.w, display.black , [],gcRect);
            lastupdate = Screen('Flip', display.w );%to clear buffer  
        end
            
    end    
    Screen('Flip', display.w );%to clear buffer  
    if iLink.doILink
        Eyelink('stoprecording');
        Eyelink('message','TRIAL_OVER');
        Eyelink('message','TRIAL_RESULTS');%add more here
    end

    %print the results of this trial to file
    fprintf(output.resultsFile,'%d\n',tr);
    
    %make sure space is released    
    [KeyIsDown, endrt, KeyCode]=KbCheck();
    while (KeyIsDown==1)
        [KeyIsDown, endrt, KeyCode]=KbCheck();
    end;
    return;
end

