function [output, display, trials] = SetUpTrials( subNo, display)
%set all variables for running the blocks.  
%these values canbe hard coded in this file, or they can be read in from a

%%%%%%%%%%%%%%%%%%%%%%
% file handling
%%%%%%%%%%%%%%%%%%%%%%

%some of these are redining the base matlab colours, but oh well.
    display.white=WhiteIndex(display.w);
    display.black=BlackIndex(display.w);
    display.grey = (WhiteIndex(display.w)+BlackIndex(display.w))/2;
    
    % Define filenames of input files and result file:
    output.filename = strcat('SimpleCue_',num2str(subNo),'.dat'); % name of cueing data file to write to

    % check for existing result file to prevent accidentally overwriting
    % files from a previous subject/session (except for subject numbers > 99):
    if subNo>99
        fopen(output.filename, 'rt');  % its a test trial
    else
        while (fopen(output.filename, 'rt')~=-1)
            subNo= subNo+1;
            output.filename = strcat('SimpleCue_',num2str(subNo),'.dat'); % name of cueing data file to write to
        end;
        strcat('Result data file already exists! Choosing: ', num2str(subNo))
    end
    output.resultsFile = fopen(output.filename,'wt'); % open ASCII file for writing
%header line
    
    
    [display.width, display.height]=Screen('WindowSize', display.w);
    
    %these variables are common to all experiment blocks
    display.centerX                   = display.width/2;
    display.centerY                   = display.height/2;
    display.screenRect = [0 0 display.width display.height];
    centW = 53.0; %screen width, cm
    centD = 80.0; %dist to screen, cm

    rad = 2.0*atan(centW/(centD*2));%radians of entire monitor
    deg = rad*(180/pi);%Degrees of entire monitor
    display.pixelsperdegree  = display.width/deg;  %pixels per degree
    
%     %No fixation needed
    display.fixXLoc                   = display.centerX;
    display.fixYLoc                   = display.centerY;    
    display.fixHalfBox                = 10;      %max distance we allow to still be on target for fix and saccade land    
    display.gcHalfBox                = floor(1*display.pixelsperdegree);;      %max distance we allow to still be on target for fix and saccade land    
    %half means the size of the square from centre to edge
    display.maxProbeResponse          = 5.0; %duration in seconds after 2nd targ
    
    display.halfStimSize              = floor(1*display.pixelsperdegree);
    %fix also potential target (but not cue)
    display.stimDir               ='Stim/';
    display.stimSearchDir               ='SearchStim/';
%every image has alpha
%alpha = 1;
    [ display.probe ] = Image2Texture( 'probe.png', display.stimDir,display.w );
    [ display.black ] = Image2Texture( 'OutlineBlack.png', display.stimDir,display.w );

    searchStim = dir([display.stimSearchDir '/*.jpg']);   
    for i=1: length(searchStim)
        imagelist(i).name = searchStim(i).name;
        imagelist(i).tex = Image2Texture( imagelist(i).name, display.stimSearchDir,display.w );
    end

    display.iterations                = 2; % 10 should get us 960 trials here ->me thinks 8*48=240 (two practice blocks?, leaves us with 30 trials per condition)... 
       
    trials = repmat(imagelist,1,display.iterations)
    display.numtrials = length(trials);
    %randomize trials
    randomOrder = randperm(size(trials,2)); %create random order from that.
    trials = trials(randomOrder);
    
end

